@@ -1,7 +1,6 @@
 #pragma once
 
 #include <limits>
-#include <stddef.h>
 
 // #define USE_LZCNT
 
@@ -10,10 +9,11 @@
 #include "defines.h"
 
 #include <atomic>
-#include <cassert>
 #include <cstdint>
 #include <type_traits>
-
+#if defined(_WIN32) && defined(__GNUC__)
+#  define USE_CLZLL
+#endif
 #ifdef pause
 #  undef pause
 #endif
@@ -75,6 +75,8 @@ namespace snmalloc
 
       return BITS - index - 1;
 #  endif
+#elif defined(USE_CLZLL)
+      return static_cast<size_t>(__builtin_clzll(x));
 #else
       return static_cast<size_t>(__builtin_clzl(x));
 #endif
